@@ -55,11 +55,11 @@ def run() :
 
     if not os.path.exists(args.case_dir) :
         print(f' {args.case_dir} 目录不存在，工作目录为：{os.getcwd()}')
-        exit(2)
+        exit(2)  #  2 表示没有可以执行的用例
 
     if not os.path.isdir(args.case_dir) :
         print(f' {args.case_dir} 不是目录，工作目录为：{os.getcwd()}')
-        exit(2)
+        exit(2) #  2 表示没有可以执行的用例
 
     # 同时执行log里面的初始化日志模块，注册signal的代码
     from hytest.utils.log import LogLevel
@@ -81,7 +81,7 @@ def run() :
 
     print(f'''           
     *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *     
-    *       hytest {version}             www.python3.vip   *
+    *       hytest {version}            www.byhy.net   *
     *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *
     '''
     )
@@ -93,7 +93,10 @@ def run() :
         tag_include_expr=tag_include_expr,
         tag_exclude_expr=tag_exclude_expr,
         )
-    Runner.run()
+
+    # 0 表示执行成功 , 1 表示有错误 ， 2 表示没有可以执行的用例
+    return Runner.run()
+
 
 if __name__ == '__main__':
-    run()
\ No newline at end of file
+    exit(run())
\ No newline at end of file
